"""Common filenames and locations for topographic data, meshes and outputs.
"""

import sys
from os import sep as s, environ
from os.path import expanduser

# Making assumptions about the location of scenario data
scenario_dirname = 'new_south_wales'+s+'wollongong_tsunami_scenario_2006'+s+'anuga'

# Filenames
basename = 'flagstaff'
demname = 'wollongong_10'
building_footprints = 'flagstaff_building_footprints'

# Parameters
base_resolution = 5
initial_sealevel = 0.0
    
# Derive subdirectories and filenames
try:
    home = environ['INUNDATIONHOME']
except Exception, e:
    print 'Environment variable INUNDATIONHOME was not found: %s' %e
    home = expanduser('~')


meshdir = home+s+scenario_dirname+s+'meshes'+s
datadir = home+s+scenario_dirname+s+'topographies'+s
outputdir = home+s+scenario_dirname+s+'output'+s
polygondir = home+s+scenario_dirname+s+'polygons'+s
gaugedir = home+s+scenario_dirname+s+'gauges'+s

demname = datadir + demname
meshname = meshdir + basename
mesh_filename = meshname + '.msh'
buildings_filename = meshdir + building_footprints + '.asc'

outputname = outputdir + basename  #Used by post processing



# Mesh data

# Lower left corner
xllcorner = 307000
yllcorner = 6188940

# Upper right corner
xurcorner = 307788
yurcorner = 6189509

# Bounding polygon
point1 = [xllcorner, (yllcorner+yurcorner)/2]
point2 = [xllcorner + (xurcorner-xllcorner)/3, yurcorner]
point3 = [xllcorner + 2*(xurcorner-xllcorner)/3, yurcorner]    
point4 = [xurcorner, yllcorner + 2*(yurcorner-yllcorner)/3]        
point5 = [xurcorner, yllcorner + (yurcorner-yllcorner)/3]    
point6 = [xllcorner + 2*(xurcorner-xllcorner)/3, yllcorner]    

bounding_polygon = [[xllcorner, yllcorner],   #sw
                    point1,
                    point2,
                    point3,
                    point4,
                    point5,
                    point6]    
    
boundary_tags = {'exterior': [0,1,5,6], 'side': [2,4], 'ocean': [3]}

interior_regions = []
        
